/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#ifndef Age_H
#define Age_H

#include "assert.h"

const int NAgeStrings = 9;
//enum AgeEnum { AGE0=0, MIN_AGE=AGE0, AGE1=1, AGE2, AGE3, AGE4, AGE5, MAX_AGE=AGE5 };

// age class to provide type safety.  static config() must be called to initialize
// the class.

class Age {
  public:
    Age() : age_(min_) 
    {
#ifdef DEBUG
        check();
#endif //DEBUG
    }
    Age(const Age& age) : age_(age.age_) 
    { 
#ifdef DEBUG
        check();
#endif //DEBUG
    }

    static void config(int min, int max); //, int firstHvAge=-1, int adultAge=-1);
    
    // this routine is explicit instead of a ctor, so as to provide no
    // default conversion from int to Age.  this is used for initializaton
    // purposes.
    void assign_from_int(const int age) 
    { age_ = age; check(); }

    // converts age enum to corresponding string
    char* string(); 

    const Age& operator++()    { age_++; return *this; }
    Age operator++(int) { Age tmp=*this; age_++; return tmp; }
    const Age& operator--()    { age_--; return *this; }
    Age operator--(int) { Age tmp=*this; age_--; return tmp; }
    operator int() const { return age_; }

    // these allow the return value optimization
    static Age bottom() { return Age(min_); }
    static Age top() { return Age(max_); }
    
private:
    // only this class can create Ages from ints
    Age(int age) : age_(age) {}
    
    // fn to increase max (called from parser)
    static void increaseMax(int max);
    void check() const;

    int age_;

    static int min_;
    static int max_;

    static char* age_strings_[NAgeStrings];

    // parser is allowed access
    friend class ConfigParser;
    friend class StockConfigParser;
};


#endif // Age_H
