/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#ifndef Array5D_H
#define Array5D_H

#include "Array4D.h"

template <class T>
class Array5D {
  public:
    Array5D() : array_(0) {}
    Array5D(int dim1, int dim2, int dim3, int dim4, int dim5)
    { createArray(dim1, dim2, dim3, dim4, dim5); }
    ~Array5D() { delete [] array_; };
    
    Array4D<T>& operator[](int index)
    { return array_[index]; }
    const Array4D<T>& operator[](int index) const
    { return array_[index]; }

    void reshape(int dim1, int dim2, int dim3, int dim4, int dim5);
    
  private:
    Array4D<T>* array_;

    void createArray(int dim1, int dim2, int dim3, int dim4, int dim5);
};

#include <rw/compiler.h>
#ifdef RW_COMPILE_INSTANTIATE
#include "Array5D.cpp"
#endif /* compile time instantiation */

#endif // Array5D_H
