/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1999  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


// CNRParser.h - Harvest CNR Parser

#ifndef CNRParser_H
#define CNRParser_H

#include "GenArrayParser.h"


class CNRParser : public GenArrayParser {
  public:
    CNRParser(Parser& p, RWCString dimension);

    virtual void parseEnd(); // this should be protected, but the compiler has trouble with it

  protected:
    virtual void processKeyword(const RWCString& token)
    { keymap_.processKeyword(*this, token); }

  private:
    friend class KeywordProcessor<CNRParser>;
    KeywordProcessor<CNRParser> keymap_;
    const RWCString dimension_; // string rep of dimensionality

    virtual void initKeymap();
    virtual void initState();
    void configCNR(State* state);
    void clearData();

    // cnr types
    enum CNRType { CnrNone, CnrHarvestRatio, CnrSeasonLength, CnrReportedEncounter, 
        CnrHarvestRatioMultipleEncounter, CnrSeasonLengthMultipleEncounter, NumCnrTypes };

    // keyword fns
    void cnrMethod();
    void harvestRatio();
    void seasonLength();
    void reportedEncounter();
    void harvestRatioMultipleEncounter();
    void seasonLengthMultipleEncounter();
    void legalSelectivity();
    void sublegalSelectivity();
    void legalSeasonLength();
    void cnrSeasonLength();
    void legalEncounters();
    void sublegalEncounters();
    void landedCatch();
    void releaseMortRate();
    void baseSeason();
    void recaptureInterval();

    // data for constructing cnr objects
    CNRType cnrType_;
    double legalSelectivity_;
    double sublegalSelectivity_;
    double legalSeasonLength_;
    double cnrSeasonLength_;
    double legalEncounters_;
    double sublegalEncounters_;
    double landedCatch_;
    double legalReleaseMortRate_;
    double baseSeason_;
    double recaptureInterval_;
};

#endif // CNRParser_H
