/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#ifndef CeilingScalarConfigParser_H
#define CeilingScalarConfigParser_H

// CeilingScalarConfigParser reads CeilingScalarConfig configuration information

#include "SubParser.h"
#include "CeilingScalarPolicyControl.h"
#include "KeywordProcessor.h"
#include "auto_ptr.h"


class CeilingScalarConfigParser : public SubParser {
  public:
    CeilingScalarConfigParser(Parser& p, const RWCString& fname,
        RWTValOrderedVector<CeilingScalarPolicyControl::CeilingScalarConfig>& configvec);
    virtual ~CeilingScalarConfigParser() {}

  protected:
    // a fn to retreive the current "context", also for error reporting
    virtual RWCString context() const;
    virtual void processKeyword(const RWCString& token)
    { keymap_.processKeyword(*this, token); }

  private:
    // parsing fns
    void parseEndKeyword();
    void year();

    // utility fns
    void initKeymap();

    // data
    friend class KeywordProcessor<CeilingScalarConfigParser>;
    KeywordProcessor<CeilingScalarConfigParser> keymap_;

    RWTValOrderedVector<CeilingScalarPolicyControl::CeilingScalarConfig>& configvec_;
    auto_ptr<CeilingScalarPolicyControl::CeilingScalarConfig> ceilingConfig_;
};

#endif // CeilingScalarConfigParser_H
