/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#include "CohortConfigParser.h"
#include "CohortParser.h"
#include "CohortTokens.h"
#include "Tokens.h"
#include "TopTokens.h"
#include "GenArrayTokens.h"

#include "globals.h"


// ctor utility fn

void CohortConfigParser::initKeymap()
{
    keymap_.insert(GenArrayTokens::STOCK, stock);
    keymap_.insert(CohortTokens::COHORT, cohort);
    keymap_.insert(Tokens::END1, parseEndKeyword);
    keymap_.insert(Tokens::END2, parseEndKeyword);
}

CohortConfigParser::CohortConfigParser(Parser& p) : SubParser(p), stock_(0), stockName_()
{
    initKeymap();
}

RWCString
CohortConfigParser::context() const
{
    return(TopTokens::COHORTS);
}

void CohortConfigParser::stock()
{
    parseVar(stockName_);
    stock_ = ::Stocks.find(stockName_);
    if (!stock_) {
        // stock not found; keep parsing and discard data
        logError(pError(ParseError::BadData, "stock not found, discarding cohort data", stockName_,
                 context()).errorMessage());
    }
}

void CohortConfigParser::cohort()
{
    // have the CohortParser take over
    CohortParser cohortParser(*this, stock_, stockName_);
    cohortParser.parse();
}

void CohortConfigParser::parseEndKeyword()
{
    if (!stockName_.isNull()) {
        // end stock; exit the current stock level
        stockName_.resize(0);
        nextDataLine(); // skip the rest of this line as comment
    }
    else {
        // end Cohorts; exit this subparser
        SubParser::parseEndKeyword();
    }
}