/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#ifndef ConfigParser_H
#define ConfigParser_H

// ConfigParser reads configuration information

#include "SubParser.h"
#include "KeywordProcessor.h"

class ConfigParser : public SubParser {
  public:
    ConfigParser(Parser& p);
    virtual ~ConfigParser() {}

  protected:
    ConfigParser(const RWCString& fileName);

    // a fn to retreive the current "context", also for error reporting
    virtual RWCString context() const;
    virtual void processKeyword(const RWCString& token)
    { keymap_.processKeyword(*this, token); }

  private:
    // parsing fns
    void parseInclude();
    void startYear();
    void endYear();
    void nTimesteps();
    void nRegions();
    void fisheryName();
    void stockName();

    // utility fns
    void initKeymap();

    // data
    friend class KeywordProcessor<ConfigParser>;
    KeywordProcessor<ConfigParser> keymap_;

    int startYear_;
};

#endif // ConfigParser_H
