/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#ifndef DataRequestManager_H
#define DataRequestManager_H

#include "pragma.h"
#include "DataRequest.h"
#include <rw/tpslist.h>

class DataRequestState;

// DataRequestManager - singleton which stores and wakes up data
// requests on schedule the .cpp file makes one static instance of
// this class.  users may make more as desired to access functions and
// data.  all memory for the data requests is deleted when the static
// instance goes out of scope.

class DataRequestManager {
  public:
    DataRequestManager()
    { ++refcount; }
    ~DataRequestManager()
    { if (!--refcount) requests.clearAndDestroy(); }
    
    static void configAll();	// configures all data requests
    static void initAll();      // initializes (clears) all data requests
    static void schedule(DataRequest*);	// assumes ownership of the DataRequest ptr
    static void removeAndDestroy(DataRequest*); // removes a previously scheduled request
    static void collect(SystemProcesses::ProcessId); // collect data for scheduled requests
    static void outputAll();
    static void simulationWrapup() { requests.clearAndDestroy(); }

    static void saveState(DataRequestState&);
    static void restoreState(const DataRequestState&);

  private:
    static int refcount;
    static RWTPtrSlist<DataRequest> requests;

    // disabled fns
    DataRequestManager(const DataRequestManager&);
    DataRequestManager& operator=(const DataRequestManager&);
};

#endif //DataRequestManager_H
