/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1999  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#include "FisheryConfigParser.h"
#include "FisheryConfigTokens.h"
#include "Tokens.h"

#include "globals.h"
#include "Fishery.h"

// ctor utility fn

void FisheryConfigParser::initKeymap()
{
    keymap_.insert(FisheryConfigTokens::FISHERYNUMBER, fisheryNumber);
    keymap_.insert(FisheryConfigTokens::GEARTYPE, gearType);
    keymap_.insert(FisheryConfigTokens::ABBREV, abbrev);
    keymap_.insert(Tokens::END1, parseEndKeyword);
    keymap_.insert(Tokens::END2, parseEndKeyword);
}

FisheryConfigParser::FisheryConfigParser(Parser& p, const RWCString& name) 
    : SubParser(p), thefishery_(new Fishery(name))
{
    initKeymap();
}

RWCString
FisheryConfigParser::context() const
{
    return("Fishery Configuration");
}

void FisheryConfigParser::
fisheryNumber()
{
    int num;
    parseVar(num);
    thefishery_->number_ = num;
}

void FisheryConfigParser::
abbrev()
{
    // cast away const
    RWCString& abbrv = const_cast<RWCString&> (thefishery_->abbrv);
    parseVar(abbrv);
}

void FisheryConfigParser::
gearType()
{
    RWCString gear;
    parseVar(gear);
    gear.toLower();
    if (gear == "troll")
        thefishery_->gear = Fishery::TROLL;
    else if (gear == "net")
        thefishery_->gear = Fishery::NET;
    else if (gear == "sport")
        thefishery_->gear = Fishery::SPORT;
    else {
        // unrecognized gear type
     	throw pError(ParseError::BadData, "unrecognized gear type", gear);
   }
}

void FisheryConfigParser::
parseEndKeyword()
{
    // commit this fishery
    Fisheries.append(thefishery_.get());
    thefishery_->index(Fisheries.num()-1);
    thefishery_.release();
    SubParser::parseEndKeyword();
}
