/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


// FisheryPolicy.h - FisheryPolicy abstract base class.  Each fishery
// must operate under exactly one FisheryPolicy for a given year,
// timestep, and region.  The harvest() fn will perform all the
// harvesting for a given FisheryUnit, subject to the particular
// policy.  The effortScalar is used to cause the harvest to occur in
// the desired fashion subject to the effects of the policy
// management.

#ifndef FisheryPolicy_H
#define FisheryPolicy_H

class FisheryUnit;

class FisheryPolicy {
  public:
    FisheryPolicy(double effortScalar) : effortScalar_(effortScalar)
    {}
    
    virtual void harvest(FisheryUnit *) = 0;
    double effortScalar() const
    { return effortScalar_; }

  protected:
    double effortScalar_;
};


#endif // FisheryPolicy_H

