/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


// FisheryQuotaPolicy.h - FisheryPolicy to perform harvest with a quota

#ifndef FisheryQuotaPolicy_H
#define FisheryQuotaPolicy_H

#include "FisheryPolicy.h"

class FisheryQuotaPolicy : public FisheryPolicy {
  public:
    // default effortScalar of 1.0
    FisheryQuotaPolicy(double quota, bool force) 
	: FisheryPolicy(1.0), quota_(quota), forceFlag_(force)
    {}

    virtual void harvest(FisheryUnit*);

  private:
//    double computeNewScalar(double unitCatch) const;
    
    double quota_;		// target number of fish
    bool forceFlag_;		// whether to increase harvest if necessary

    static const double tolerance_;	// meet the quota within this tolerance
    static const double xtolerance_; // minimum tolerance for change in effort
    static const int maxIter_;		// maximum iterations before failure
};

#endif // FisheryQuotaPolicy_H

