/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#ifndef FisheryRegionTimeStockAgeArray_H
#define FisheryRegionTimeStockAgeArray_H

#include "GenericArray.h"
#include "Array5D.h"

// a generic array subclass which provides for a generic array indexed
// by fishery, region, time, stock, and age.

template <class T>
class FisheryRegionTimeStockAgeArray : public GenericArray<T> {
  public:
    FisheryRegionTimeStockAgeArray(size_t nFisheries, size_t nRegions, size_t nSteps,
				   size_t nStocks, size_t nAges)
	: nFisheries_(nFisheries), nRegions_(nRegions), nSteps_(nSteps), nStocks_(nStocks),
	  nAges_(nAges), 
	  array_(nFisheries, nRegions, nSteps, nStocks, nAges)
    {}
    
    FisheryRegionTimeStockAgeArray(size_t nFisheries, size_t nRegions, size_t nSteps,
				   size_t nStocks, size_t nAges, const T& dfltVal);

    // generic interface
    virtual const T& operator[](const GenericArrayIndex& id) const
    { return array_[id.fisheryIndex]
	  	   [id.regionIndex]
	  	   [id.timeIndex]
	  	   [id.stockIndex]
		   [id.age]; }


    virtual T& operator[](const GenericArrayIndex& id)
    { return array_[id.fisheryIndex]
	  	   [id.regionIndex]
	  	   [id.timeIndex]
	  	   [id.stockIndex]
		   [id.age]; }

    virtual void newGenericIndexList(RWTPtrOrderedVector<GenericArrayIndex>&) const;
        
  private:
    size_t nFisheries_;
    size_t nRegions_;
    size_t nSteps_;
    size_t nStocks_;
    size_t nAges_;

    Array5D<T> array_;
};

#include <rw/compiler.h>
#ifdef RW_COMPILE_INSTANTIATE
#include "FisheryRegionTimeStockAgeArray.cpp"
#endif /* compile time instantiation */

#endif // FisheryRegionTimeStockAgeArray_H
