/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1999  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#include "FisheryRegionTimeStockAgeMarkArray.h"
#include <rw/tpslist.h>


template <class T>
FisheryRegionTimeStockAgeMarkArray<T>::
FisheryRegionTimeStockAgeMarkArray(size_t nFisheries, size_t nRegions, size_t nSteps,
			       size_t nStocks, size_t nAges, size_t nMarks, const T& dfltVal)
    : nFisheries_(nFisheries), nRegions_(nRegions), nSteps_(nSteps), nStocks_(nStocks),
      nAges_(nAges), nMarks_(nMarks),
      array_(nFisheries, nRegions, nSteps, nStocks, nAges, nMarks)
{
    for (int f=0; f<nFisheries_; ++f) {
        for (int l=0; l<nRegions_; ++l) {
            for (int ts=0; ts<nSteps_; ++ts) {
                for (int s=0; s<nStocks_; ++s) {
                    for (int a=0; a<nAges_; ++a) {
                        for (int m=0; m<nMarks_; ++m) {
                            array_[f][l][ts][s][a][m] = dfltVal;
                        }
                    }
                }
            }
        }
    }
}

// append to a list of GenericArrayIndex one new entry (on the heap) for each index in the array.
template <class T>
void
FisheryRegionTimeStockAgeMarkArray<T>::newGenericIndexList(RWTPtrOrderedVector<GenericArrayIndex>& indexList) const
{
    for (int f=0; f<nFisheries_; ++f) {
        for (int l=0; l<nRegions_; ++l) {
            for (int ts=0; ts<nSteps_; ++ts) {
                for (int s=0; s<nStocks_; ++s) {
                    for (int a=0; a<nAges_; ++a) {
                        for (int m=0; m<nMarks_; ++m) {
                            GenericArrayIndex* id = new GenericArrayIndex(0, f, l, 0, ts);
                            id->stockIndex = s;
                            id->age = a;
                            id->mark = m;
                            indexList.append(id);
                        }
                    }
                }
            }
        }
    }
}

    
