/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#include "FisheryYearStockArray.h"
#include <rw/tpslist.h>


template <class T>
FisheryYearStockArray<T>::
FisheryYearStockArray(size_t nFisheries, size_t nYears, size_t nStocks,
		      const T& dfltVal)
    : nFisheries_(nFisheries), nYears_(nYears), nStocks_(nStocks),
      array_(nFisheries, nYears, nStocks)
{
    for (int f=0; f<nFisheries_; ++f) {
	for (int y=0; y<nYears_; ++y) {
	    for (int s=0; s<nStocks_; ++s) {
		array_[f][y][s] = dfltVal;
	    }
	}
    }
}

// append to a list of GenericArrayIndex one new entry (on the heap) for each index in the array.
template <class T>
void FisheryYearStockArray<T>::
newGenericIndexList(RWTPtrOrderedVector<GenericArrayIndex>& indexList) const
{
    for (int f=0; f<nFisheries_; ++f) {
        for (int y=0; y<nYears_; ++y) {
            for (int s=0; s<nStocks_; ++s) {
                GenericArrayIndex* id = new GenericArrayIndex(0, f, 0, y, 0);
                id->stockIndex = s;
                indexList.append(id);
            }
        }
    }
}



    

    
