/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


// Factory which knows how to build all types of Generic Arrays.  This
// is a stateless class.

#ifndef GenericArrayFactory_H
#define GenericArrayFactory_H

#include <rw/tpslist.h>
#include <rw/cstring.h>

#include "GenericArray.h"

template <class T>
class GenericArrayFactory {
  public:
    GenericArrayFactory();

    // all types of generic arrays
    enum GenericArrayType
    { TimeStep, 
      StockAgeTime, 
      StockYear, StockYearTimeRegion,
      StockYearAgeTime, StockYearAgeTimeRegion, StockYearAgeTimeMaturity, 
      FisheryRegionTimeStockAge, FisheryRegionTimeStockAgeMark, 
      FisheryYearAge, FisheryYearStock, FisheryYearStockAge,
	  FisheryYear, FisheryYearRunAge, Fishery,
      RunAgeMaturityTime,
      MaturityTime, 
      NTypes
    };

    // strings to match each type.  this should be static, but our
    // compiler won't handle it in a template.
    const char* GenericArrayTypeStrings[NTypes];

    // build a new array of a particular dynamic type.  dimension
    // sizes maxima by default, or are passed in the appropriate
    // fields of the GenericArrayIndex parameter.  the caller is
    // responsible for deleting this array.
    GenericArray<T>* newGenericArrayFn0(GenericArrayFactory<T>::GenericArrayType);
    GenericArray<T>* newGenericArrayFn1(GenericArrayFactory<T>::GenericArrayType, const T& dfltVal);
    GenericArray<T>* newGenericArrayFn2(GenericArrayFactory<T>::GenericArrayType, const GenericArrayIndex&);
    GenericArray<T>* newGenericArrayFn3(GenericArrayFactory<T>::GenericArrayType, const GenericArrayIndex&, const T& dfltVal);

    // return the type code for the given string; return NTypes if not found
    GenericArrayType genericArrayType(const RWCString typestring) const;
};

#include <rw/compiler.h>
#ifdef RW_COMPILE_INSTANTIATE
#include "GenericArrayFactory.cpp"
#endif /* compile time instantiation */

#endif // GenericArrayFactory_H
