/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#include "Geographer.h"
#include "log.h"

unsigned int Geographer::nRegions_ = 0;  // bad vaule by default

DestructiveRegionList Geographer::regions_;


void Geographer::config(unsigned int nRegions)
{
    nRegions_ = nRegions; 
    
    // initialize the region list
    regions_.clearAndDestroy();
    for (int i=0; i < nRegions_; ++i) {
        regions_.insert(new Region(i));
    }
}

void Geographer::checkConfig()
{
    if (nRegions_ < 1) {
        ::LogMsg(L_Fatal, "at least one Region must be specified!\nexiting...\n");
    }
}


// find and return a requested region by index
//   precondition: requested region must exist

const Region& Geographer::
region(int loc)
{
    RegionIter reg(regions_);
    while (++reg) {
	if (reg.key()->index() == loc)
	    return *reg.key();
    }
    // should never get here, but keeps the compiler happy
    assert(false); return *reg.key();
}
