/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


// HarvestProcess.cpp

//#ifdef DEBUG
#include "log.h"
#include "Fishery.h"
//#endif // DEBUG

#include "HarvestProcess.h"
#include "HarvestManager.h"
#include "HvMort.h"

double LinearHarvestProcess::
computeCatch(const HvMort& hvmort, double policyScalar) const 
{
//    HarvestManager hvm;		// system monostate
    double hvrate = HarvestManager::hvRate(&hvmort) * HarvestManager::pv(&hvmort)  * policyScalar;

//#ifdef DEBUG
    if (hvrate > 1.0) {
        ::LogMsg(L_Warning, "harvest rate %.2lf for %s, \n"
            "\t%s, in %s\n",
            hvrate, hvmort.cohort().stock()->get_name(), hvmort.cohort().age().string(),
            hvmort.fishery().get_name());
    }
//#endif    

    return (hvmort.cohortAbundance() * hvrate);
}

// boundedHarvest.  new style of harvest computation, currently
// used on a limited basis.  almost identical to terminal_harvest() above.
// eventually may become the standard harvest fn.
//
// precondition: catchability already set

//void HvMort::boundedHarvest()
//{
//    legalCatch_ = cohort_.abundance(region_) *
//		(1.0 - exp(-catchability_ * fishery_.policy_hv_scalar()));
//}

