/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1999  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

// Historian.h - system monostate which records some basic information as the simulation 
// progresses for general use.

#ifndef Historian_H
#define Historian_H

class Fishery;
class TrackDetailedFisheryCatches;
class TimeStamp;


class Historian {
  public:
    Historian() {}

    static void init();

    // this is the average catch for a fishery in a region and timestep over a range of years
    static double basePeriodAverageCatch(const Fishery* fishery, int region, int time, 
                                         int baseStartYearIndex, int baseEndYearIndex);
    static double basePeriodTotalAverageCatch(const Fishery* fishery, 
                                         int baseStartYearIndex, int baseEndYearIndex);
    // total catch for a fishery over a time period
    static double totalCatch(const Fishery* fishery, const TimeStamp& first, const TimeStamp& last);

  private:
    static TrackDetailedFisheryCatches* fisheryCatches_;
};


#endif // Historian_H