/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#include "KeywordProcessor.h"

// KeywordProcessor implementations.

// processKeyword.  Look up the requested token and call the
// corresponding member fn.  Tokens not found in the keymap will
// generate "BadKey" ParseError exceptions.  Other ParseError
// exceptions thrown while the mapped member fn is executing will be
// caught and output here.  Recovery will be attempted by processing
// the offending token as the next keyword, where appropriate.
// Otherwise the exception will be rethrown.

template <class T>
void KeywordProcessor<T>::
processKeyword(T& parser, RWCString keyw) const
{
    RWBoolean loop;
    do {
        loop = FALSE;
        try {
            PMFn fnptr;
            if (!keymap_.findValue(keyw, fnptr))
                throw parser.pError(ParseError::BadKey, "bad keyword", keyw,
                parser.context());
            else
                (parser.*fnptr)();
        } 
        catch (ParseError& err) {
            // if the error token differs from the current keyword, output
            // the error here and attempt to process the offending token
            // as the next keyword.  otherwise rethrow the exception.
            if (err.token() != keyw) {
                err.context(keyw);
                parser.logError(err.errorMessage());
                if (!err.token().isNull()) {
                    //		    processKeyword(parser, err.token());
                    keyw = err.token();
                    loop = TRUE;
                }
            }
            else 
                throw;
        }
    } while (loop);
}
