/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


// LineBuffer implementations

#include "ParseError.h"
#include "LineBuffer.h"

// ctor attempts to open the file, and throws an exception upon failure.
// NOTE separators and operators for the lexical analyzer can be passed
//  in, if the defaults are not suitable.
LineBuffer::LineBuffer(const RWCString& fileName, 
					   const char* separators, const char* operators)
: fileName_(fileName), lineCount_(0), 
               tokenizer_(0, separators, operators)
{
    ifs_.open(fileName);
    if (!ifs_)
        throw ParseError(fileName, 0, ParseError::BadFile,
        "unable to open file");
}

// read next line and return it, also preparing the tokenizer to
// handle this new line.  return null on EOF.
const char * 
LineBuffer::nextLine() {
    if (ifs_.getline(buf_, LineSize)) {
        updateTokenizer();
        lineCount_++;
        return buf_;
    } else if (ifs_.bad())
        throw ParseError(ParseError::BadRead);
    // eof
    clearTokenizer();
    return 0;
}

// return next token
// return null RWCString if no more tokens on line.

RWCString
LineBuffer::nextLineToken() {
    char* token = tokenizer_.token();
    if (token)
        return token;
    else
        return RWCString();
}

// make new tokenizer for buf_, get peekToken_.
void
LineBuffer::updateTokenizer()
{
    tokenizer_.lexString(buf_);
}

// clear tokenizer, clear tokens.
void
LineBuffer::clearTokenizer() {
    tokenizer_.lexString(0);
}

