/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

// LinearProduction.h - spawn fish via a linear function

#ifndef LinearProduction_H
#define LinearProduction_H

#include "ProductionFunction.h"


class LinearProduction : public ProductionFunction {
  public:
    LinearProduction(double minSpawners, double maxSpawners, double ev, double slope)
        : minSpawners_(minSpawners), maxSpawners_(maxSpawners), ev_(ev), slope_(slope)
    {}

    virtual double spawn(double escapement) const;

    virtual const ProductionFunction* clone() const
    { return new LinearProduction(*this); }

  private:
      double minSpawners_;
      double maxSpawners_;
      double ev_;
      double slope_;
};


#endif // LinearProduction_H
