/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#ifndef MigrationManager_H
#define MigrationManager_H

#include "GenericArray.h"
#include "RCPtr.h"
#include "auto_ptr.h"

class Chronograph;
class TransitionMatrix;
typedef GenericArray<RCPtr<TransitionMatrix> > TransMatRepository;

// Migration Manager monostate - this object is not valid until the
// config() method has been called to establish a table of transition
// matrices.

class MigrationManager {
  public:
    MigrationManager() {}
    
    static void config(TransMatRepository*);
    static void init();  // check for proper configuration

    static void migrateCohorts();

    // add new transition matrices, at config time.  passed are
    // RCPointers to TMs which should be on the heap.  the memory will
    // be handled here, by the Migration Manager, from then on.
    static void insertTransitionMatrix(const RCPtr<TransitionMatrix>& tmat,
				       const GenericArrayIndex& index);
    
  private:
    static auto_ptr<GenericArray<RCPtr<TransitionMatrix> > > transitionMatrices_;
};

#endif // MigrationManager_H
