/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


// NamedPtrVec.cc

#include <string.h>
#include "NamedPtrVec.h"

// construct from a val vector

template <class T>
NamedPtrVec<T>::NamedPtrVec(T* data, const int n)
    : RWTPtrOrderedVector<T>(n)
{
    for (int i=0; i < n; ++i)
	insert(data + i);
}

// op=

template <class T>
NamedPtrVec<T>& NamedPtrVec<T>::operator=(const NamedPtrVec<T>& v)
{
    if (&v != this) 
	return (NamedPtrVec<T> &) RWTPtrOrderedVector<T>::operator=(v);
    else return *this;
}


// find fn, assuming presence of "get_name()" and "get_abbrv()" fns in template class

template <class T>
T* NamedPtrVec<T>::find(const char *nm) const
{
    NamedPtrVec<T>* mythis = (NamedPtrVec<T>*) this;
    for (size_t i = 0; i < entries(); ++i)
    {
	if (strcmp(nm, (*mythis)[i].get_name()) == 0
	    || strcmp(nm, (*mythis)[i].get_abbrv()) == 0)

	    return &(*mythis)[i];
    }
    return 0;
}


