/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#include "OutputPSCStockEscapements.h"
#include "OutputEscapementState.h"
#include "Stocks.h"
#include "SystemClock.h"
#include "SpawningManager.h"
#include "iotools.h"


// copy ctor makes a deep copy
OutputPSCStockEscapements::OutputPSCStockEscapements(const OutputPSCStockEscapements& rhs)
  :  fname_(rhs.fname_)
{   
    // use the assignment operator for RWGenMat to get a deep copy
    config();
    escapements = rhs.escapements;
}

// assignment operator also makes deep copy
OutputPSCStockEscapements& OutputPSCStockEscapements::
operator=(const OutputPSCStockEscapements& rhs)
{
    if (this != &rhs) {
        config();
        fname_ = rhs.fname_;
        escapements = rhs.escapements;
    }
    return *this;
}

void OutputPSCStockEscapements::
config()
{
    escapements.reshape(::Stocks.num(), Chronograph::nYears());
    clear();
}

void OutputPSCStockEscapements::
collect(SystemProcesses::ProcessId process)
{
    if (process == SystemProcesses::SP_Maturation) {
        for (int i=0; i < escapements.rows(); ++i) {
            for (unsigned region=0; region < Geographer::nRegions(); ++region) {
                GenericArrayIndex gendex(*::SystemClock);
                gendex.stockIndex = i;
                gendex.regionIndex = region;
                if (SpawningManager::getProduction(gendex)) {
                    escapements(i, Chronograph::currentYearIndex()) +=
                        Stocks[i].adultMatureRegionalAbundance(region);
                }
            }
        }
    }
}


void OutputPSCStockEscapements::
output()
{
    FILE *fp = 0;
    
    if (open_outfile(fp, fname_))
        return;  // should probably throw exception here
    
    // write data
    for (int year = 0; year < Chronograph::nYears(); ++year) {
        fprintf(fp, "%d\t", Chronograph::baseYear() + year);
        for (int i = 0; i < escapements.rows(); ++i) {
            fprintf(fp, "%.0f\t", escapements(i, year));
        }
        fprintf(fp, "\n");
    }
    fclose(fp);
}

State* OutputPSCStockEscapements::
newSaveState()
{
    return (new OutputEscapementState(this)); 
}
