/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


// OutputStockEscapements.h - DataRequest object which tracks and outputs
// adult escapements by stock and year

#ifndef OutputPSCStockEscapements_H
#define OutputPSCStockEscapements_H

#include "pragma.h"

#include <rw/math/genmat.h>
#include <rw/cstring.h>
#include "DataRequest.h"

class OutputPSCStockEscapements : public DataRequest {
  public:
    OutputPSCStockEscapements(RWCString fname)
        : fname_(fname)
    { config(); }
    // copy ctor makes a deep copy
    OutputPSCStockEscapements(const OutputPSCStockEscapements&);
    // as does the assignment operator
    OutputPSCStockEscapements& operator=(const OutputPSCStockEscapements&);

    virtual void config();
    virtual void collect(SystemProcesses::ProcessId);
    virtual void output();
    virtual void clear() { escapements = 0;}

    virtual State* newSaveState(); 
    
  private:
    RWGenMat<double> escapements;
    RWCString fname_;
};


#endif // OutputPSCStockEscapements_H
