/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1999  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


// PSCCustomShaker derived class

#ifndef PSCCustomShaker_H
#define PSCCustomShaker_H

#include "PSCShaker.h"
#include "GenericArray.h"
#include "VulnerabilityTable.h"


// PSC custom style shakers.  This class uses a configured vulnerability table
// to determine whether to include a given harvest in the weighted pnv calculations.

class PSCCustomShaker : public PSCShaker {
  public:
    PSCCustomShaker(double rate, const VulnerabilityTable& vtab)
        : PSCShaker(rate), vulnerability_(vtab)
    {}

    virtual ~PSCCustomShaker() {}
    
  protected:
    virtual bool vulnerable(const HvMort*) const;  // is this harvest vulnerable?

  private:
    const VulnerabilityTable vulnerability_;
};
    
#endif // PSCCustomShaker_H
