/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


// PSCShaker derived class

#ifndef PSCShaker_H
#define PSCShaker_H

#include "Shaker.h"
#include "HvMort.h"

// PSC style shakers
class PSCShaker : public Shaker {
  public:
    PSCShaker(double rate) : Shaker(), shakerMortRate_(rate)
    {}
    virtual ~PSCShaker() {}
    
    virtual void setShakers(Fishery*) const;
    virtual double subLegalShakerMortRate() const { return shakerMortRate_; }
    virtual double dropOffMortRate() const { return 0.0; }
    virtual double totalSubLegalCnrMortRate() const { return shakerMortRate_; }
    virtual double dropOffs(const HvMort*) const { return 0.0; }
    
  protected:
    virtual bool vulnerable(const HvMort* harvest) const  // is this harvest vulnerable?
    { return (harvest->cohortAbundance() > 0.0); }

    double shakerMortRate_;
};
    
#endif // PSCShaker_H
