/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

// PSC_CohortGenerator.cpp

#include "PSC_CohortGenerator.h"
#include "CohortManager.h"

const unsigned PSC_CohortGenerator::age0Region_ = 0;  // region for age0 fish in PSC model

void PSC_CohortGenerator::
newAge0Cohorts(double abd, unsigned region, const Stock* stock, unsigned broodyear)
{
    if (abd > 0.0) {
        CohortList existingCohorts;
        CohortManager::findPendingCohorts(stock, broodyear, existingCohorts);
        Cohort* cohort;
        if (existingCohorts.entries() > 0) {
            // this class expects at most one existing cohort, but we are allowing
            // for the possibility that it was created in an earlier timestep
            cohort = existingCohorts(0);
        }
        else {
            // the current psc model however expects to create one new age0 cohort 
            // each year.  the CohortManager retains a handle to the new cohort.
            CohortID id(stock, broodyear);
            cohort = CohortManager::newPendingCohort(id);
        }
        // this class ignores the passed in region and always uses a fixed region
        cohort->abundance(age0Region_) += abd;
    }
}
