/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#ifndef ParseError_H
#define ParseError_H

// ParseError class - a simple container for parse error information,
// suitable as a fn return or exception tossing.

#include <rw/cstring.h>

class ParseError {
  public:
    enum Erc { Ok=0, BadFile, BadRead, BadKey, BadType, BadData,
	       Eof, LogicError, Other };

    ParseError() : code_(Other), msg_("Unknown"), lineNumber_(0) {}
    ParseError(Erc code) : code_(code), lineNumber_(0) {}
    ParseError(const RWCString& fileName,
	       long lineNumber,
	       Erc code = Other,
	       const RWCString& msg = "Unknown",
	       const RWCString& token  = "",
	       const RWCString& context = "")
	: fileName_(fileName), lineNumber_(lineNumber), code_(code),
	  msg_(msg), token_(token), context_(context)
    {}

    operator int() const { return code_; }

    // return the full error message
    RWCString errorMessage() const;

    // accessors
    const RWCString& fileName() const { return fileName_; }
    long lineNumber() const { return lineNumber_; }
//    const RWCString& msg() const { return msg_; }
    const RWCString& context() const { return context_; }
    const RWCString& token() const { return token_; }
    Erc code() const { return code_; }

    // allow the message or context strings to be overwritten
//    void msg(const RWCString& msg) { msg_ = msg; }
    void context(const RWCString& context) { context_ = context; }
    
  private:
    RWCString fileName_;
    long lineNumber_;
    RWCString msg_;
    RWCString context_;		// current context
    RWCString token_;		// offending token
    Erc code_;
};


#endif // ParseError_H
