/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

// Production.cpp

#include "Production.h"
#include "ProductionFunction.h"


// the prod fns vector will grow if necessary, but is likely to stay small
Production::Production() : prodFns_(4)
{}

// prod fns are destroyed on exit by auto_ptr
Production::~Production()
{}


// compute spawned fish by adding the results of the production fns
double Production::
spawn(double escapement) const
{
    double spawned = 0;
    for (int i=0; i < prodFns_.entries(); ++i) {
        spawned += prodFns_(i)->spawn(escapement);
    }
    return spawned;
}


// insert a new production function.  
void Production::
insertProductionFunction(auto_ptr<const ProductionFunction> prodFn)
{
    prodFns_.insert(prodFn);
}

