/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


/******************************************************************************
*                                                                             *
* Code from Item 29: Reference Counting of MORE EFFECTIVE C++ by Scott Meyers *
*									      *
*                                                                             *
*                            September 19, 1996                               *
*                                                                             *
*            Copyright 1996 (c) Addison-Wesley Publishing Company             *
*       You are free to use this code for non-commercial purposes only.       *
*                                                                             *
* This page contains the code for the classes and class templates making up   *
* the Reference Counting Item of More Effective C++.  
*                                                                             *
* Each class or template in this file follows a block comment that shows the  *
* corresponding pages in the book.
*                                                                             *
* Scott Meyers                                                                *
*                                                                             *
******************************************************************************/

/*****************************************************************************
 * I modified this code to remove the virtual destructor in RCObject,
 * making the class more lightweight.  This means the burden for
 * destruction is now on the client of RCObject (specifically, RCPtr).
 * removeReference therefore now returns the resulting refCount, so
 * that the decision of whether or not to destroy can be made by the
 * client.  I also inlined everything in RCObject to make it more
 * compact.  Finally, I commented out the "unshareable" feature, since
 * I don't feel it applys well to the general case of reference
 * counting.
 *
 * twf 3/18/97
 *****************************************************************************/

/******************************************************************************
*                       Class RCObject (from pp. 204-205)                     *
******************************************************************************/

#ifndef RCObject_H
#define RCObject_H

// The following is for compilers that don't support bool.  Comment these
// lines out if your compilers do support bool.  For details on this emulation
// of bool, see More Effective C++, pp. 3-4.
#include "Bool.h"

class RCObject {                       // base class for reference-
  public:                              // counted objects
    void addReference()
      { ++refCount; }

    int removeReference()
      { return (--refCount); }

//    void markUnshareable()
//      { shareable = false; }

//    bool isShareable() const
//      { return shareable; } 

    bool isShared() const
      { return refCount > 1; }

  protected:
    RCObject() : refCount(0) //, shareable(true)
    {}
    RCObject(const RCObject&) : refCount(0)  //, shareable(true)
    {}
    RCObject& operator=(const RCObject&)
    { return *this; }

    ~RCObject() {}

  private:
    int refCount;
//    bool shareable;
};

#endif // RCObject_H
