/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

// RickerProduction.cpp

#include "RickerProduction.h"
#include <math.h>

// spawning function.  simple Ricker, but for only the number of
// spawners lying within the predetermined range.

double RickerProduction::
spawn(double escapement) const
{
    if (escapement <= minSpawners_)
        return 0;
    else {
        if (escapement > maxSpawners_)
            escapement = maxSpawners_;
//            escapement = rickerB_ / rickerA_;
        double spawners = escapement - minSpawners_;

        double age0fish = ((spawners * exp(rickerA_ * (1.0 - (spawners / rickerB_))))
                           / age1Recruits_) * ev_;

        return age0fish;
    }
}

