/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

// RickerProduction.h - spawn fish via a Ricker function

#ifndef RickerProduction_H
#define RickerProduction_H

#include "ProductionFunction.h"


class RickerProduction : public ProductionFunction {
  public:
    RickerProduction(double minSpawners, double maxSpawners, double ev,
                     double rickerA, double rickerB, double age1Recruits)
        : minSpawners_(minSpawners), maxSpawners_(maxSpawners), ev_(ev),
          rickerA_(rickerA), rickerB_(rickerB), age1Recruits_(age1Recruits)
    {}

    virtual double spawn(double escapement) const;

    virtual const ProductionFunction* clone() const
    { return new RickerProduction(*this); }

  private:
    double minSpawners_;
    double maxSpawners_;
    double ev_;
    double rickerA_;
    double rickerB_;
    double age1Recruits_;
};


#endif // RickerProduction_H
