/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#include "StockYearAgeTimeArray.h"
#include <rw/tpslist.h>

template <class T>
RunAgeMaturityTimeArray<T>::
RunAgeMaturityTimeArray(size_t nRuns, size_t nAges, size_t nMaturityStates, size_t nSteps, const T& dfltVal)
    : nRuns_(nRuns), nAges_(nAges), nMaturityStates_(nMaturityStates), nSteps_(nSteps),
array_(nRuns, nAges, nMaturityStates, nSteps)
{
    for (int r=0; r<nRuns_; ++r) {
        for (int a=0; a<nAges_; ++a) {
            for (int m=0; m<nMaturityStates_; ++m) {
                for (int ts=0; ts<nSteps_; ++ts) {
                    array_[r][a][m][ts] = dfltVal;
                }
            }
        }
    }
}    

// append to a list of GenericArrayIndex one new entry (on the heap) for each index in the array.
template <class T>
void RunAgeMaturityTimeArray<T>::
newGenericIndexList(RWTPtrOrderedVector<GenericArrayIndex>& indexList) const
{
    for (unsigned r=0; r<nRuns_; ++r) {
        for (unsigned a=0; a<nAges_; ++a) {
            for (unsigned m=0; m<nMaturityStates_; ++m) {
                for (unsigned ts=0; ts<nSteps_; ++ts) {
                    GenericArrayIndex* id = new GenericArrayIndex((unsigned)0, ts);
                    id->run = r;
                    id->age = a;
                    id->maturityIndex = m;
                    indexList.append(id);
                }
            }
        }
    }
}

