/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

// SDS_Cabn.h - Standard Data Sentence Cohort Abundance class

#ifndef SDS_Cabn_H
#define SDS_Cabn_H

#include "StandardDataSentence.h"
#include "DataRequest.h"

// SDS_Cabn handles the output of the CABN (cohort abundance) type of 
// Standard Data Sentence.  It uses the DataRequest interface to wake
// up at the proper times for the collection of abundance data, then 
// ouputs the data immediately using the StandardDataSentence interface.
// The ctor expects to receive an open ofstream for this output.  This
// ofstream resource is managed elsewhere.

class SDS_Cabn : public DataRequest, private StandardDataSentence {
  public:
    SDS_Cabn(ofstream& outfile);

    virtual void config() {}
    virtual void collect(SystemProcesses::ProcessId);
    virtual void output() {}
    virtual void clear()  {}

    virtual State* newSaveState(); 

  private:
    static const char* cabnId_;
};

#endif // SDS_Cabn_H

