/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

// SDS_Nmrt.h - Standard Data Sentence Natural Mortality class

#ifndef SDS_Nmrt_H
#define SDS_Nmrt_H

#include "StandardDataSentence.h"
#include "DataRequest.h"

// SDS_Nmrt handles the output of the NMRT (natural mortality) type of
// Standard Data Sentence.  It uses the DataRequest interface to wake
// up at the proper times for the collection of natmort data, then
// ouputs the data immediately using the StandardDataSentence
// interface.  The ctor expects to receive an open ofstream for this
// output.  This ofstream resource is managed elsewhere.

class SDS_Nmrt : public DataRequest, private StandardDataSentence {
  public:
    SDS_Nmrt(ofstream& outfile);

    virtual void config() {}
    virtual void collect(SystemProcesses::ProcessId);
    virtual void output() {}
    virtual void clear()  {}

    virtual State* newSaveState(); 

  private:
    static const char* nmrtId_;
};

#endif // SDS_Nmrt_H

