/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1999  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


// ShakerParser.h - Harvest Shaker Parser

#ifndef ShakerParser_H
#define ShakerParser_H

#include "GenArrayParser.h"
#include "VulnerabilityTable.h"

// the harvest parser is a generic array parser

class ShakerParser : public GenArrayParser {
  public:
    ShakerParser(Parser& p, RWCString dimension);

    virtual void parseEnd();

  protected:
    virtual void processKeyword(const RWCString& token)
    { keymap_.processKeyword(*this, token); }

  private:
    friend class KeywordProcessor<ShakerParser>;
    KeywordProcessor<ShakerParser> keymap_;
    const RWCString dimension_; // string rep of dimensionality

    virtual void initKeymap();
    virtual void initState();
    void configShaker(State* state);
    void clearData();

    // parsing keywords
    void method();
    void simpleMethod();
    void customMethod();
    void simpleDropMethod();
    void customDropMethod();
    void subLegalReleaseMortRate();
    void dropOffRate();
    void vulnerabilityTable();

    // local data
    enum ShakerType { ShakerNone, ShakerSimple, ShakerCustom, ShakerSimpleDrop, ShakerCustomDrop };

    ShakerType shakerType_;
    double subLegalReleaseMortRate_;
    double dropOffRate_;
    VulnerabilityTable vulnerabilityTable_;
    bool vtabInit_; // flag whether the vulnerability table has been initialized
};

#endif // ShakerParser_H
