/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#ifndef SpawningManager_H
#define SpawningManager_H

#include "GenericArray.h"
#include "auto_ptr.h"

// production table
class Production;
class ProductionFunction;
typedef GenericArray<auto_ptr<Production> > ProductionTable;

class SpawningManager {
  public:
    SpawningManager() {}
    
    static void spawnCohorts();

    // production data config
    static void config();  // reconfig with default (empty) table
    static void configProduction(auto_ptr<ProductionTable> newTable); // reconfig with new table
    static void insertProductionFunction(auto_ptr<const ProductionFunction> prodFn, 
                                         const GenericArrayIndex& gendex);

    // getProduction returns null if no Production configured at the given gendex
    static Production* getProduction(const GenericArrayIndex& gendex)
    { return (*productionTable_)[gendex].get(); }

  private:
    static auto_ptr<ProductionTable> productionTable_;
};


#endif // SpawningManager_H
