/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1999  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

// StandardDataSentenceState.h - state class for all StandardDataSentence subclasses

#include "State.h"
#include <fstream.h>


// Saving state only occurs when this object is constructed.  The output stream is passed
// in and a reference to it is kept.  The current location of the output pointer is also
// saved using tellp().  This is then restored using seekp() when restoreState() is called.

class StandardDataSentenceState : public State {
  public:
    StandardDataSentenceState(ofstream& output) : output_(output), location_(output.tellp())
    {}

    virtual void restoreState() const;      // restore state to stored value

  protected:
    virtual void saveState()                // take a snapshot of current state
    {}  // all functionality occurs in the ctor

  private:
    ofstream& output_;
    streampos location_;
};