/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1999  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

// State.h - abstract class to hold a snapshot of some state

#ifndef State_H
#define State_H

// this is an abstract base class to hold a snapshot of some portion of system state.

class State {
  public:
    // saveState is called by the ctor
    State() {}
    virtual ~State() {}

    virtual void restoreState() const = 0;      // restore state to stored value

  protected:
    // this requires each derived class to support this interface.  the saveState()
    // method should be called in the derived class ctor
    virtual void saveState() = 0;               // take a snapshot of current state
};

#endif // State_h