/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1999  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#ifndef StockConfigParser_H
#define StockConfigParser_H

// StockConfigParser reads configuration information

#include "SubParser.h"
#include "KeywordProcessor.h"
#include "auto_ptr.h"
#include "Stock.h"

class StockConfigParser : public SubParser {
  public:
    StockConfigParser(Parser& p, const RWCString& name);
    virtual ~StockConfigParser() {}

  protected:
    // a fn to retreive the current "context", also for error reporting
    virtual RWCString context() const;
    virtual void processKeyword(const RWCString& token)
    { keymap_.processKeyword(*this, token); }
    virtual void parseEndKeyword();

  private:
    // parsing fns
    void stockNumber();
    void abbrev();
    void productionType();
    void run();
    void maxAge();
    void adultAge();
    void firstHvAge();
    
    // utility fns
    void initKeymap();

    // data
    friend class KeywordProcessor<StockConfigParser>;
    KeywordProcessor<StockConfigParser> keymap_;

    auto_ptr<Stock> theStock_;
};

#endif // StockConfigParser_H
