/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#include "StockYearAgeTimeArray.h"
#include <rw/tpslist.h>

template <class T>
StockYearAgeTimeArray<T>::
StockYearAgeTimeArray(size_t nStocks, size_t nYears, size_t nAges, size_t nSteps, const T& dfltVal)
: nStocks_(nStocks), nYears_(nYears), nAges_(nAges), nSteps_(nSteps),
array_(nStocks, nYears, nAges, nSteps)
{
    for (int s=0; s<nStocks_; ++s) {
        for (int y=0; y<nYears_; ++y) {
            for (int a=0; a<nAges_; ++a) {
                for (int ts=0; ts<nSteps_; ++ts) {
                    array_[s][y][a][ts] = dfltVal;
                }
            }
        }
    }
}    

// append to a list of GenericArrayIndex one new entry (on the heap) for each index in the array.
template <class T>
void StockYearAgeTimeArray<T>::
newGenericIndexList(RWTPtrOrderedVector<GenericArrayIndex>& indexList) const
{
    for (unsigned s=0; s<nStocks_; ++s) {
        for (unsigned y=0; y<nYears_; ++y) {
            for (unsigned a=0; a<nAges_; ++a) {
                for (unsigned ts=0; ts<nSteps_; ++ts) {
                    GenericArrayIndex* id = new GenericArrayIndex(y, ts);
                    id->stockIndex = s;
                    id->age = a;
                    indexList.append(id);
                }
            }
        }
    }
}

