/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#ifndef StockYearAgeTimeMatureArray_H
#define StockYearAgeTimeMatureArray_H

#include "GenericArray.h"
#include "Array5D.h"

// a generic array subclass which provides for a generic array indexed
// by stock, year, age, timestep, and maturity.

template <class T>
class StockYearAgeTimeMatureArray : public GenericArray<T> {
  public:
    StockYearAgeTimeMatureArray(size_t nStocks, size_t nYears, size_t nAges,
				size_t nSteps, size_t nMatureStates)
	: nStocks_(nStocks), nYears_(nYears), nAges_(nAges), nSteps_(nSteps),
	  nMatureStates_(nMatureStates),
	  array_(nStocks, nYears, nAges, nSteps, nMatureStates)
    {}
    
    StockYearAgeTimeMatureArray(size_t nStocks, size_t nYears, size_t nAges,
				size_t nSteps, size_t nMatureStates, const T& dfltVal);
    
    // generic interface
    virtual const T& operator[](const GenericArrayIndex& id) const
    { return array_[id.stockIndex]
	  	   [id.yearIndex]
	  	   [id.age]
	  	   [id.timeIndex]
	           [id.maturityIndex]; }

    virtual T& operator[](const GenericArrayIndex& id)
    { return array_[id.stockIndex]
	  	   [id.yearIndex]
	  	   [id.age]
	  	   [id.timeIndex]
	  	   [id.maturityIndex]; }

    virtual void newGenericIndexList(RWTPtrOrderedVector<GenericArrayIndex>&) const;
        
  private:
    size_t nStocks_;
    size_t nYears_;
    size_t nAges_;
    size_t nSteps_;
    size_t nMatureStates_;

    Array5D<T> array_;
};

#include <rw/compiler.h>
#ifdef RW_COMPILE_INSTANTIATE
#include "StockYearAgeTimeMatureArray.cpp"
#endif /* compile time instantiation */

#endif // StockYearAgeTimeMatureArray_H
