/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1999  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#include "StockYearTimeRegionArray.h"
#include <rw/tpslist.h>


template <class T>
StockYearTimeRegionArray<T>::
StockYearTimeRegionArray(size_t nStocks, size_t nYears, 
                         size_t nSteps, size_t nRegions, const T& dfltVal)
    : nStocks_(nStocks), nYears_(nYears), nSteps_(nSteps), nRegions_(nRegions),
      array_(nStocks, nYears, nSteps, nRegions)
{
    for (int s=0; s<nStocks_; ++s) {
        for (int y=0; y<nYears_; ++y) {
            for (int ts=0; ts<nSteps_; ++ts) {
                for (int l=0; l<nRegions_; ++l) {
                    array_[s][y][ts][l] = dfltVal;
                }
            }
        }
    }
}

// append to a list of GenericArrayIndex one new entry (on the heap) for each index in the array.
template <class T>
void StockYearTimeRegionArray<T>::
newGenericIndexList(RWTPtrOrderedVector<GenericArrayIndex>& indexList) const
{
    for (int s=0; s<nStocks_; ++s) {
        for (int y=0; y<nYears_; ++y) {
            for (int ts=0; ts<nSteps_; ++ts) {
                for (int l=0; l<nRegions_; ++l) {
                    GenericArrayIndex* id = new GenericArrayIndex(0, 0, l, y, ts);
                    id->stockIndex = s;
                    indexList.append(id);
                }
            }
        }
    }
}

    
