/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#ifndef SubParser_H
#define SubParser_H

// SubParser class.  This class inherits from Parser and provides a
// different implementation of the virtual parse() to allow for forced
// exit, instead of always reading to the end of file.  It can only be
// constructed from another parser.  It is still an abstract base
// class, due to the pure virtual fn processKeyword().

#include "Parser.h"

class SubParser : public Parser {
  public:
    SubParser(Parser& parser)
	: Parser(parser), forceDone_(FALSE), fromFile_(FALSE)
    {}
    virtual ~SubParser() {}

    virtual void parse();

  protected:
    SubParser(const RWCString& fileName, ParserErrorLogger *pel)
	: Parser(fileName, pel), forceDone_(FALSE), fromFile_(TRUE)
    {}

    virtual void processKeyword(const RWCString&) = 0;

    // force early return of the parsing loop. 
    void forceDone()
    { forceDone_ = TRUE; }

    // clear the forceDone flag, to allow continuation
    void clearDone()
    { forceDone_ = FALSE; }
    
    // generic way to process "end" keyword for a subparser
    virtual void parseEndKeyword();

    // a fn to retreive the current "context", also for error reporting
    // the subparser must always define this
    virtual RWCString context() const = 0;

  private:
    // done flag to force early exit.  
    RWBoolean forceDone_;

    // Remember whether we were started from a filename or a copy
    //  constructor.
    RWBoolean fromFile_;
};

#endif // SubParser_H

