// this method is private and called only by the ctor, so we can assume that data is blank
/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1999  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

// SystemState.cpp - take and restore snapshots of system state

#include "SystemState.h"
#include "CohortState.h"
#include "DataRequestState.h"


SystemState::SystemState() : State() 
{ 
    // create a new stateRep_ on the heap.  this is automatically destroyed by RCPtr when
    // the last copy goes out of scope.
    stateRep_ = new StateRep;
    saveState(); 
}

SystemState::~SystemState()
{}

void SystemState::saveState()
{
    stateRep_->stateComponents_.clearAndDestroy();

    // construct a state object for each of the state components and add them to the list
    stateRep_->stateComponents_.insert(new CohortState);
    stateRep_->stateComponents_.insert(new DataRequestState);
}

// the restore method walks the component list and executes a "restore" on each
void SystemState::restoreState() const 
{
    RWTPtrSlist<State>::const_iterator ptr = stateRep_->stateComponents_.begin();
    while (ptr != stateRep_->stateComponents_.end()) {
        (*ptr)->restoreState();
        ++ptr;
    }
}

