/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


#ifndef TimeStepArray_H
#define TimeStepArray_H

#include <rw/tvvector.h>
#include <rw/tpslist.h>
#include "GenericArray.h"
#include "Chronograph.h"

// a generic array subclass which provides for a single dimensional
// array indexed by timestep.

template <class T>
class TimeStepArray : public GenericArray<T> {
  public:
    TimeStepArray()
    {}
    TimeStepArray(size_t timesteps)
	: array_(timesteps) {}

    TimeStepArray(size_t timesteps, const T& dfltVal);

    // generic interface
    virtual const T& operator[](const GenericArrayIndex& id) const
    { return array_(id.timeIndex); }

    virtual T& operator[](const GenericArrayIndex& id)
    { return array_(id.timeIndex); }

    virtual void newGenericIndexList(RWTPtrOrderedVector<GenericArrayIndex>& indexList) const
    { for (int ts=0; ts<array_.length(); ++ts)
	  indexList.append(new GenericArrayIndex(int(0), ts));
    }

    // specific interface
    virtual const T& operator[](size_t i) const
    { return array_(i); }

    virtual T& operator[](size_t i)
    { return array_(i); }

    void reshape(size_t n)
    { array_.reshape(n); }
    
  private:
    RWTValVector<T> array_;
};

#include <rw/compiler.h>
#ifdef RW_COMPILE_INSTANTIATE
#include "TimeStepArray.cpp"
#endif /* compile time instantiation */

#endif // TimeStepArray_H
