/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1999  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/

// TrackDetailedFisheryCatchState.h - State derived class which holds all variable state information 
// resident in an TrackDetailedFisheryCatches object

#ifndef TrackDetailedFisheryCatchState_H
#define TrackDetailedFisheryCatchState_H

#include "State.h"
#include "TrackDetailedFisheryCatches.h"
#include "auto_ptr.h"


class TrackDetailedFisheryCatchState : public State {
  public:
      TrackDetailedFisheryCatchState(TrackDetailedFisheryCatches* data) 
          : savedState_(new TrackDetailedFisheryCatches(*data)), originalPtr_(data)
      {}
      virtual ~TrackDetailedFisheryCatchState()
      {}

      virtual void restoreState() const;      // restore state to stored value

  protected:
      virtual void saveState() {}           // handled by ctor

  private:
    // this class saves state just by copying the TrackDetailedFisheryCatches object
    // use auto_ptr to delete old storage
    auto_ptr<TrackDetailedFisheryCatches> savedState_;

    // a handle to the original object is also saved
    TrackDetailedFisheryCatches* originalPtr_;
};


#endif // TrackDetailedFisheryCatchState_H
