/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


// Transition Matrix

#ifndef TransitionMatrix_H
#define TransitionMatrix_H

#include <rw/math/genmat.h>

#include "AbundanceMatrix.h"
#include "RCObject.h"
#include "RCPtr.h"

// the transition matrix is used to determine migration from one
// region to another.  columns are "from" and rows are "to".
// inherits privately from RCObject to support reference counting.

class TransitionMatrix : private RCObject {
  public:
    TransitionMatrix(unsigned nRegions) 
	    : transMat_(nRegions, nRegions, 0) {}
    TransitionMatrix(unsigned nRegions, const double* initialData)
    	: transMat_(initialData, nRegions, nRegions) {}
    TransitionMatrix(const RWGenMat<double>& mat)
	{ transMat_ = mat.deepCopy(); }
    
    // calculate a transition
    void transition(const AbundanceVector& from, AbundanceVector& to) const;
    
    // make the individual matrix elements directly accessible
    double val(int to, int from) const
    { return transMat_(to, from); }
    
  private:
    RWGenMat<double> transMat_;

    double& operator() (int row, int col) // private data access
    { return transMat_(row, col); }
    
    friend class TransMatParser; // data input access
    friend class RCPtr<TransitionMatrix>; // ref count ptr access
};


#endif // TransitionMatrix_H
