/**********************************************************************
  Pacific Coast Harvest Model - a coastal piscatorial simulation
  Copyright (C) 1998  Troy Frever, Columbia Basin Research, University of Washington
     
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
     
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  For questions regarding this program, please contact:

  Troy Frever or Jim Norris
  UW Columbia Basin Research
  Box 358218
  University of Washington
  Seattle, WA  98195
  troy@u.washington.edu

**********************************************************************/


// engine module 
#include <iostream.h>
#include "SystemClock.h"
#include "Stock.h"
#include "StockList.h"
#include "Fishery.h"
#include "FisheryManager.h"
#include "NaturalMortalityManager.h"
#include "MigrationManager.h"
#include "MaturationManager.h"
#include "SpawningManager.h"
#include "CohortManager.h"
#include "Chronograph.h"
#include "DataRequestManager.h"
#include "IterationManager.h"
#include "SystemProcesses.h"
#include "init.h"
#include "log.h"
#include "SystemState.h"

/* main engine for the nmfs coastal simulation.  */

void RunTheModel()
{
    for (::SystemClock->resetClock(); !(::SystemClock->yearExpired()); ::SystemClock->incrementYear()) {
        ::LogMsg(L_Msg, "year %d\n", ::SystemClock->currentCalendarYear());

        for (::SystemClock->resetTimeSteps(); !(::SystemClock->timeExpired()); 
             ::SystemClock->incrementTimeStep()) {

            // the IterationManager could reset the SystemClock to an earlier time
            IterationManager::beginTimeStep();

            // aging up to the current year/time needs to happen before any data collection
            CohortManager::ageCohorts();

            DataRequestManager::collect(SystemProcesses::SP_BeforeFirstProcess);
            
            NaturalMortalityManager::takeNaturalMortality();
            DataRequestManager::collect(SystemProcesses::SP_NaturalMortality);
            
            FisheryManager::takeHarvests();
            DataRequestManager::collect(SystemProcesses::SP_Harvest);

            MaturationManager::maturateCohorts();
            DataRequestManager::collect(SystemProcesses::SP_Maturation);
            
            SpawningManager::spawnCohorts();
            DataRequestManager::collect(SystemProcesses::SP_Spawn);
            
            MigrationManager::migrateCohorts();
            DataRequestManager::collect(SystemProcesses::SP_Migration);

            IterationManager::endTimeStep();
        }
    }
}

